Exception: ActiveRecord::Duplicator::InvalidRecordIdError

Inherits:
Error
  • Object
show all
Defined in:
lib/active_record/duplicator/errors.rb,
sig/generated/active_record/duplicator/errors.rbs

Overview

Raised when store_duplicate_id (or no_duplicate) tries to overwrite an existing mapping with a different new_id. This typically indicates a bug in the calling code or a handler.